[Zope3-checkins] CVS: Zope3/src/zope/app/services - configure.zcml:1.18 event.py:1.17 servicenames.py:1.3

R. Sean Bowman sean.bowman@acm.org
Sat, 8 Mar 2003 16:46:39 -0500


Update of /cvs-repository/Zope3/src/zope/app/services
In directory cvs.zope.org:/tmp/cvs-serv32568/zope/app/services

Modified Files:
	configure.zcml event.py servicenames.py 
Log Message:
changed EventDispatch to EventPublication, modified some zcml to be more
consistent with the new service names


=== Zope3/src/zope/app/services/configure.zcml 1.17 => 1.18 ===
--- Zope3/src/zope/app/services/configure.zcml:1.17	Fri Mar  7 11:56:46 2003
+++ Zope3/src/zope/app/services/configure.zcml	Sat Mar  8 16:46:08 2003
@@ -379,7 +379,7 @@
 <!-- Error reporting service -->
 
   <serviceType
-      id="ErrorReportingService"
+      id="ErrorLogging"
       interface="zope.app.interfaces.services.error.IErrorReportingService" />
 
   <content class='zope.app.services.errorr.ErrorReportingService'>
@@ -388,7 +388,7 @@
         interface="zope.app.interfaces.services.error.IErrorReportingService"
         />
     <factory
-        id='ErrorReportingService'
+        id='ErrorLogging'
         permission='zope.Public' />
     </content>
 
@@ -400,7 +400,7 @@
 
   <content class='zope.app.services.hub.ObjectHub'>
     <factory
-        id='ObjectHub'
+        id='HubIds'
         permission='zope.ManageServices' />
     <require
         permission="zope.View"


=== Zope3/src/zope/app/services/event.py 1.16 => 1.17 ===
--- Zope3/src/zope/app/services/servicenames.py:1.2	Fri Mar  7 19:51:43 2003
+++ Zope3/src/zope/app/services/servicenames.py	Sat Mar  8 16:46:08 2003
@@ -20,7 +20,7 @@
 from zope.component.servicenames import *
 
 HubIds = 'HubIds'
-EventDispatch = 'Events'
+EventPublication = 'Events'
 EventSubscription = 'Subscription'
 ErrorLogging = 'ErrorReportingService'
 Roles = 'Roles'
--- Zope3/src/zope/app/services/event.py:1.16	Fri Mar  7 19:51:43 2003
+++ Zope3/src/zope/app/services/event.py	Sat Mar  8 16:46:08 2003
@@ -28,7 +28,8 @@
 
 from zope.component import getAdapter, queryAdapter, getService, queryService
 from zope.component import ComponentLookupError
-from zope.app.services.servicenames import HubIds, EventDispatch, EventSubscription
+from zope.app.services.servicenames import HubIds, EventPublication
+from zope.app.services.servicenames import EventSubscription
 from zope.app.component.nextservice import getNextService, queryNextService
 
 from zope.proxy.context import ContextMethod, ContextSuper
@@ -329,7 +330,7 @@
         try:
             clean_self._notify(wrapped_self, event)
             if clean_self.isPromotableEvent(event):
-                getNextService(wrapped_self, EventDispatch).publish(event)
+                getNextService(wrapped_self, EventPublication).publish(event)
         finally:
             publishedEvents.remove(event)
     publish = ContextMethod(publish)
@@ -344,7 +345,7 @@
 
     def bound(wrapped_self, name):
         "See IBindingAware"
         # An event service is bound as EventSubscription and as EventDispatch.
         # We only want to subscribe to the next event service when we're bound
         # as EventSubscription
         if name == EventSubscription:
@@ -361,7 +362,7 @@
 
     def unbound(wrapped_self, name):
         "See IBindingAware"
         # An event service is bound as EventSubscription and as EventDispatch.
         # We only want to unsubscribe from the next event service when
         # we're unbound as EventSubscription
         if name == EventSubscription:
@@ -344,7 +345,7 @@
     def bound(wrapped_self, name):
         "See IBindingAware"
-        # An event service is bound as EventSubscription and as EventDispatch.
+        # An event service is bound as EventSubscription and EventPublication.
         # We only want to subscribe to the next event service when we're bound
         # as EventSubscription
@@ -361,7 +362,7 @@
     def unbound(wrapped_self, name):
         "See IBindingAware"
-        # An event service is bound as EventSubscription and as EventDispatch.
+        # An event service is bound as EventSubscription and EventPublication.
         # We only want to unsubscribe from the next event service when
         # we're unbound as EventSubscription


=== Zope3/src/zope/app/services/servicenames.py 1.2 => 1.3 ===